<?php
/**
 * rubik-theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package rubik-theme
 */

if ( ! function_exists( 'rubik_theme_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function rubik_theme_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on rubik-theme, use a find and replace
		 * to change 'rubik-theme' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'rubik-theme', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'rubik-theme' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'rubik_theme_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'rubik_theme_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rubik_theme_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'rubik_theme_content_width', 640 );
}
add_action( 'after_setup_theme', 'rubik_theme_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rubik_theme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'rubik-theme' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'rubik-theme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'rubik_theme_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rubik_theme_scripts() {
    wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css', array() );
    wp_enqueue_style( 'fontawesome-css', get_template_directory_uri() . '/css/font-awesome.min.css', array() );
    wp_enqueue_style( 'slick-css', get_template_directory_uri() . '/css/slick.css', array() );
    wp_enqueue_style( 'slick-theme-css', get_template_directory_uri() . '/css/slick-theme.css', array() );
    wp_enqueue_style( 'odometer-css', get_template_directory_uri() . '/css/odometer-theme-default.css', array() );
    wp_enqueue_style( 'rubik-theme-style', get_stylesheet_uri() );

    wp_enqueue_script( 'rubik-theme-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
    wp_enqueue_script( 'rubik-theme-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
    wp_enqueue_script( 'jquery-js', get_template_directory_uri() . '/js/jquery-3.1.0.min.js', array());
    wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array());
    wp_enqueue_script( 'slick-js', get_template_directory_uri() . '/js/slick.min.js', array());
    wp_enqueue_script( 'isotope-js', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array());
    wp_enqueue_script( 'odometer-js', get_template_directory_uri() . '/js/odometer.min.js', array());
    wp_enqueue_script( 'main-js', get_template_directory_uri() . '/js/main.js', array());

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rubik_theme_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Required plugins
 */
require_once get_template_directory() . '/inc/required.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// disable for posts
add_filter('use_block_editor_for_post', '__return_false', 10);

// disable for post types
add_filter('use_block_editor_for_post_type', '__return_false', 10);

add_post_type_support( 'page', 'excerpt' );

// Theme Customizer
function rubik_customizer( $wp_customize ) {

    // theme options panel
    $wp_customize->add_panel( 'rubik_theme_options', array(
        'title' => 'Footer',
        'description' => 'Configure rubik Theme Options',
        'priority' => 999,
    ) );

    // social media
    $wp_customize->add_section( 'rubik_main', array(
        'title' => 'Social Media',
        'priority' => 1,
        'panel' => 'rubik_theme_options',
    ));

    $wp_customize->add_setting('facebook', array('default' => ''));
    $wp_customize->add_control('facebook',
        array(
            'label' => 'Facebook Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'facebook'
        )
    );
    $wp_customize->add_setting('instagram', array('default' => ''));
    $wp_customize->add_control('instagram',
        array(
            'label' => 'Instagram Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'instagram'
        )
    );
    $wp_customize->add_setting('twitter', array('default' => ''));
    $wp_customize->add_control('twitter',
        array(
            'label' => 'Twitter Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'twitter'
        )
    );
    $wp_customize->add_setting('google-plus', array('default' => ''));
    $wp_customize->add_control('google-plus',
        array(
            'label' => 'Google Plus Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'google-plus'
        )
    );
    $wp_customize->add_setting('rss', array('default' => ''));
    $wp_customize->add_control('rss',
        array(
            'label' => 'RSS Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'rss'
        )
    );
    $wp_customize->add_setting('linkedin', array('default' => ''));
    $wp_customize->add_control('linkedin',
        array(
            'label' => 'Linkedin Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'linkedin'
        )
    );
    $wp_customize->add_setting('skype', array('default' => ''));
    $wp_customize->add_control('skype',
        array(
            'label' => 'Skype Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'skype'
        )
    );
    $wp_customize->add_setting('vimeo', array('default' => ''));
    $wp_customize->add_control('vimeo',
        array(
            'label' => 'Vimeo Link:',
            'section' => 'rubik_main',
            'type' => 'text',
            'settings' => 'vimeo'
        )
    );

    // get started
    $wp_customize->add_section( 'rubik_get_started', array(
        'title' => 'Get Started',
        'priority' => 1,
        'panel' => 'rubik_theme_options',
    ));

    $wp_customize->add_setting('get-started-img');
    $wp_customize->add_control(
        new WP_Customize_Upload_Control(
            $wp_customize,
            'get-started-img',
            array(
                'label' => 'Get Started Image',
                'section' => 'rubik_get_started',
                'settings' => 'get-started-img'
            )
        )
    );
    $wp_customize->add_setting('get-started-title', array('default' => ''));
    $wp_customize->add_control('get-started-title',
        array(
            'label' => 'Get Started Title:',
            'section' => 'rubik_get_started',
            'type' => 'text',
            'settings' => 'get-started-title'
        )
    );
    $wp_customize->add_setting('get-started-subtitle', array('default' => ''));
    $wp_customize->add_control('get-started-subtitle',
        array(
            'label' => 'Get Started Subtitle:',
            'section' => 'rubik_get_started',
            'type' => 'text',
            'settings' => 'get-started-subtitle'
        )
    );
    $wp_customize->add_setting('get-started-btn-title', array('default' => ''));
    $wp_customize->add_control('get-started-btn-title',
        array(
            'label' => 'Get Started Button Title:',
            'section' => 'rubik_get_started',
            'type' => 'text',
            'settings' => 'get-started-btn-title'
        )
    );
    $wp_customize->add_setting('get-started-btn-link', array('default' => ''));
    $wp_customize->add_control('get-started-btn-link',
        array(
            'label' => 'Get Started Button Link:',
            'section' => 'rubik_get_started',
            'type' => 'text',
            'settings' => 'get-started-btn-link'
        )
    );

}
add_action('customize_register', 'rubik_customizer');

// Slider Posts
add_action('init', 'slider_post_type');
function slider_post_type() {
    $labels = array(
        'name'               => _x( 'Home Slider', '', 'rubik' ),
        'singular_name'      => _x( 'Home Slider', '', 'rubik' ),
        'menu_name'          => _x( 'Home Slider', '', 'rubik' ),
        'name_admin_bar'     => _x( 'Home Slider', '', 'rubik' ),
        'add_new'            => _x( 'Add new Slider', '', 'rubik' ),
        'add_new_item'       => __( 'Add new Slider', 'rubik' ),
        'new_item'           => __( 'New', 'rubik' ),
        'edit_item'          => __( 'Edit Slider', 'rubik' ),
        'view_item'          => __( 'View Slider', 'rubik' ),
        'all_items'          => __( 'All Slider', 'rubik' ),
        'search_items'       => __( 'Search Slider', 'rubik' ),
        'not_found'          => __( 'No Slider found', 'rubik' ),
        'not_found_in_trash' => __( 'No Slider in Trash', 'rubik' )
    );

    $args = array(
        'labels'             => $labels,
        'description'        => __( 'Description', 'rubik' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'show_in_nav_menus'  => false,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'slider' ),
        'menu_icon'          => 'dashicons-format-gallery',
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'supports'           => array( 'title', 'thumbnail', 'excerpt' ),
        'taxonomies'  => array( 'category' ),
    );

    register_post_type('slider', $args);
}

// Case Study Slider
add_action('init', 'case_slider_post_type');
function case_slider_post_type() {
    $labels = array(
        'name'               => _x( 'Case Slider', '', 'rubik' ),
        'singular_name'      => _x( 'Case Slider', '', 'rubik' ),
        'menu_name'          => _x( 'Case Slider', '', 'rubik' ),
        'name_admin_bar'     => _x( 'Case Slider', '', 'rubik' ),
        'add_new'            => _x( 'Add new Slider', '', 'rubik' ),
        'add_new_item'       => __( 'Add new Slider', 'rubik' ),
        'new_item'           => __( 'New', 'rubik' ),
        'edit_item'          => __( 'Edit Slider', 'rubik' ),
        'view_item'          => __( 'View Slider', 'rubik' ),
        'all_items'          => __( 'All Slider', 'rubik' ),
        'search_items'       => __( 'Search Slider', 'rubik' ),
        'not_found'          => __( 'No Slider found', 'rubik' ),
        'not_found_in_trash' => __( 'No Slider in Trash', 'rubik' )
    );

    $args = array(
        'labels'             => $labels,
        'description'        => __( 'Description', 'rubik' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'show_in_nav_menus'  => false,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'case_slider' ),
        'menu_icon'          => 'dashicons-images-alt',
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'supports'           => array( 'title', 'thumbnail', 'editor' ),
        'taxonomies'  => array( 'category' ),
    );

    register_post_type('case_slider', $args);
}

// Services Slider
add_action('init', 'service_slider_post_type');
function service_slider_post_type() {
    $labels = array(
        'name'               => _x( 'Service Slider', '', 'rubik' ),
        'singular_name'      => _x( 'Service Slider', '', 'rubik' ),
        'menu_name'          => _x( 'Service Slider', '', 'rubik' ),
        'name_admin_bar'     => _x( 'Service Slider', '', 'rubik' ),
        'add_new'            => _x( 'Add new Slider', '', 'rubik' ),
        'add_new_item'       => __( 'Add new Slider', 'rubik' ),
        'new_item'           => __( 'New', 'rubik' ),
        'edit_item'          => __( 'Edit Slider', 'rubik' ),
        'view_item'          => __( 'View Slider', 'rubik' ),
        'all_items'          => __( 'All Slider', 'rubik' ),
        'search_items'       => __( 'Search Slider', 'rubik' ),
        'not_found'          => __( 'No Slider found', 'rubik' ),
        'not_found_in_trash' => __( 'No Slider in Trash', 'rubik' )
    );

    $args = array(
        'labels'             => $labels,
        'description'        => __( 'Description', 'rubik' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'show_in_nav_menus'  => false,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'service_slider' ),
        'menu_icon'          => 'dashicons-images-alt2',
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'supports'           => array( 'title', 'thumbnail', ),
        'taxonomies'  => array( 'category' ),
    );

    register_post_type('service_slider', $args);
}

// Portfolio
add_action('init', 'portfolio_post_type');
function portfolio_post_type() {
    $labels = array(
        'name'               => _x( 'Portfolio', '', 'rubik' ),
        'singular_name'      => _x( 'Portfolio', '', 'rubik' ),
        'menu_name'          => _x( 'Portfolio', '', 'rubik' ),
        'name_admin_bar'     => _x( 'Portfolio', '', 'rubik' ),
        'add_new'            => _x( 'Add new Portfolio', '', 'rubik' ),
        'add_new_item'       => __( 'Add new Portfolio', 'rubik' ),
        'new_item'           => __( 'New', 'rubik' ),
        'edit_item'          => __( 'Edit Portfolio', 'rubik' ),
        'view_item'          => __( 'View Portfolio', 'rubik' ),
        'all_items'          => __( 'All Portfolio', 'rubik' ),
        'search_items'       => __( 'Search Portfolio', 'rubik' ),
        'not_found'          => __( 'No Portfolio found', 'rubik' ),
        'not_found_in_trash' => __( 'No Portfolio in Trash', 'rubik' )
    );

    $args = array(
        'labels'             => $labels,
        'description'        => __( 'Description', 'rubik' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'show_in_nav_menus'  => false,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'portfolio' ),
        'menu_icon'          => 'dashicons-portfolio',
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'supports'           => array( 'title', 'thumbnail'),
        // 'taxonomies'  => array( 'category' ),
    );

    register_post_type('portfolio', $args);
}


// Let us create Taxonomy for Custom Post Type
add_action( 'init', 'crunchify_create_deals_custom_taxonomy', 0 );
 
//create a custom taxonomy name it "type" for your posts
function crunchify_create_deals_custom_taxonomy() {
 
  $labels = array(
    'name' => _x( 'Types', 'taxonomy general name' ),
    'singular_name' => _x( 'Type', 'taxonomy singular name' ),
    'search_items' =>  __( 'Search Types' ),
    'all_items' => __( 'All Types' ),
    'parent_item' => __( 'Parent Type' ),
    'parent_item_colon' => __( 'Parent Type:' ),
    'edit_item' => __( 'Edit Type' ), 
    'update_item' => __( 'Update Type' ),
    'add_new_item' => __( 'Add New Type' ),
    'new_item_name' => __( 'New Type Name' ),
    'menu_name' => __( 'Types' ),
  );    
 
  register_taxonomy('types',array('portfolio'), array(
    'hierarchical' => true,
    'labels' => $labels,
    'show_ui' => true,
    'show_admin_column' => true,
    'query_var' => true,
    'rewrite' => array( 'slug' => 'type' ),
  ));
}

// Evolution
add_action('init', 'evolution_post_type');
function evolution_post_type() {
    $labels = array(
        'name'               => _x( 'Evolution', '', 'rubik' ),
        'singular_name'      => _x( 'Evolution', '', 'rubik' ),
        'menu_name'          => _x( 'Evolution', '', 'rubik' ),
        'name_admin_bar'     => _x( 'Evolution', '', 'rubik' ),
        'add_new'            => _x( 'Add new Evolution', '', 'rubik' ),
        'add_new_item'       => __( 'Add new Evolution', 'rubik' ),
        'new_item'           => __( 'New', 'rubik' ),
        'edit_item'          => __( 'Edit Evolution', 'rubik' ),
        'view_item'          => __( 'View Evolution', 'rubik' ),
        'all_items'          => __( 'All Evolution', 'rubik' ),
        'search_items'       => __( 'Search Evolution', 'rubik' ),
        'not_found'          => __( 'No Evolution found', 'rubik' ),
        'not_found_in_trash' => __( 'No Evolution in Trash', 'rubik' )
    );

    $args = array(
        'labels'             => $labels,
        'description'        => __( 'Description', 'rubik' ),
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'show_in_nav_menus'  => false,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'evolution' ),
        'menu_icon'          => 'dashicons-chart-area',
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'supports'           => array( 'title', 'thumbnail', ),
        'taxonomies'  => array( 'category' ),
    );

    register_post_type('evolution', $args);
}